Module: Sass::Script::Functions

Defined in:
lib/modular-scale.rb

Overview

This is where any custom SassScript should be placed. The functions will be available on require of your extension without the need for users to import any partials. Uncomment below.

Instance Method Summary collapse

Instance Method Details

#ms_gem_installedObject

Let modularscale know that this was installed via Compass



30
31
32
# File 'lib/modular-scale.rb', line 30

def ms_gem_installed()
  Sass::Script::Bool.new(true)
end